@@ -104,6 +104,8 @@ class LevelsGroupBox(QtGui.QWidget):
         self.__settings = settings
         #: (:obj:`bool`) expert mode
         self.__expertmode = expertmode
+        #: (:obj:`list` <:obj:`int`>) rgb channel indexes
+        self.__rgbchannels = (-1, -1, -1)
 
         #: (:obj:`dict` < :obj:`str`, :obj:`dict` < :obj:`str`,`any`> >
         #                custom gradients
@@ -121,6 +123,8 @@ class LevelsGroupBox(QtGui.QWidget):
         self.__channels = None
         #: (:obj: `int`) channel to display
         self.__dchl = 0
+        #: (:obj:`bool`) gradient colors flag
+        self.__gradientcolors = False
 
         self.__ui.minDoubleSpinBox.setMinimum(-10e20)
         self.__ui.minDoubleSpinBox.setMaximum(10e20)
@@ -134,10 +138,41 @@ class LevelsGroupBox(QtGui.QWidget):
                 Gradients.keys():
             self._addGradientItem(name)
 
-        self.__histogram = HistogramHLUTWidget(
-            bins='auto', step='auto',
-            expertmode=expertmode)
-        self.__ui.histogramLayout.addWidget(self.__histogram)
+        self.__histograms = [
+            HistogramHLUTWidget(bins='auto', step='auto',
+                                expertmode=expertmode),
+            HistogramHLUTWidget(bins='auto', step='auto',
+                                expertmode=expertmode),
+            HistogramHLUTWidget(bins='auto', step='auto',
+                                expertmode=expertmode)
+        ]
+        self.__histogram = self.__histograms[0]
+        self.__histconnect = [False, False, False]
+
+        self.__onLevelsSlots = [
+            self._onLevelsChanged,
+            self._onLevelsChanged1,
+            self._onLevelsChanged2
+        ]
+        self.__changeGradientSlots = [
+            self._changeGradient0,
+            self._changeGradient1,
+            self._changeGradient2
+        ]
+        self.__saveGradientSlots = [
+            self._saveGradient,
+            self._saveGradient1,
+            self._saveGradient2
+        ]
+        self.__removeGradientSlots = [
+            self._removeGradient,
+            self._removeGradient1,
+            self._removeGradient2
+        ]
+        self.__rgbstatus = False
+        self.__ui.histogramLayout.addWidget(self.__histograms[0])
+        self.__ui.histogramLayout.addWidget(self.__histograms[1])
+        self.__ui.histogramLayout.addWidget(self.__histograms[2])
 
         self.__ui.gradientComboBox.currentIndexChanged.connect(
             self._updateGradient)
@@ -159,6 +194,10 @@ class LevelsGroupBox(QtGui.QWidget):
         self.__ui.autofactorLineEdit.textChanged.connect(
             self._onAutoFactorChanged)
         self.__connectHistogram()
+        self.__histograms[0].show()
+        self.__histograms[1].hide()
+        self.__histograms[2].hide()
+        # print(self.__histogram.isVisible())
         self.updateLevels(0.1, 1.0)
         self.__connectMinMax()
         self.__levelmode = "mono"
@@ -192,7 +231,7 @@ class LevelsGroupBox(QtGui.QWidget):
         :param status: button status
         :type status: :obj:`bool`
         """
-        if _PQGVER >= 1100:
+        if self.__gradientcolors:
             if status:
                 self.__dchl = 0
                 self._updateLevelLabels()
@@ -202,6 +241,17 @@ class LevelsGroupBox(QtGui.QWidget):
                 self.updateLevels(self.__minval, self.__maxval)
                 if self.__histogram:
                     self.__histogram.switchLevelMode('mono')
+        elif _PQGVER >= 1100:
+            if status:
+                self.__dchl = 0
+                if not self.__ui.gradientLabel.isVisible():
+                    self._updateLevelLabels()
+                    if not self.__histo:
+                        self.__histogram.switchLevelMode('mono')
+                    self.__levelmode = "mono"
+                    self.updateLevels(self.__minval, self.__maxval)
+                    if self.__histogram:
+                        self.__histogram.switchLevelMode('mono')
 
     @QtCore.pyqtSlot(bool)
     def _redLevelMode(self, status):
@@ -210,19 +260,36 @@ class LevelsGroupBox(QtGui.QWidget):
         :param status: button status
         :type status: :obj:`bool`
         """
-        if _PQGVER >= 1100:
+        if self.__gradientcolors:
             if status:
                 self.__dchl = 1
                 self._updateLevelLabels()
                 if not self.__histo:
-                    self.__histogram.switchLevelMode('rgba')
+                    self.__histogram.switchLevelMode('mono')
                 self.__levelmode = "rgba"
                 if self.__channels is not None:
                     while len(self.__channels) < 1:
-                        self.__channels.append((self.__minval, self.__maxval))
+                        self.__channels.append(
+                            (self.__minval, self.__maxval))
                     self.updateLevels(None, None, self.__channels)
                 if self.__histogram:
-                    self.__histogram.switchLevelMode('rgba')
+                    self.__histogram.switchLevelMode('mono')
+                self.setGradient(self.__histograms[0].gradient.name, 0)
+        elif _PQGVER >= 1100:
+            if status:
+                self.__dchl = 1
+                if self.__ui.gradientLabel.isVisible():
+                    self._updateLevelLabels()
+                    if not self.__histo:
+                        self.__histogram.switchLevelMode('rgba')
+                    self.__levelmode = "rgba"
+                    if self.__channels is not None:
+                        while len(self.__channels) < 1:
+                            self.__channels.append(
+                                (self.__minval, self.__maxval))
+                        self.updateLevels(None, None, self.__channels)
+                    if self.__histogram:
+                        self.__histogram.switchLevelMode('rgba')
 
     @QtCore.pyqtSlot(bool)
     def _greenLevelMode(self, status):
@@ -231,19 +298,36 @@ class LevelsGroupBox(QtGui.QWidget):
         :param status: button status
         :type status: :obj:`bool`
         """
-        if _PQGVER >= 1100:
+        if self.__gradientcolors:
             if status:
                 self.__dchl = 2
                 self._updateLevelLabels()
                 if not self.__histo:
-                    self.__histogram.switchLevelMode('rgba')
+                    self.__histogram.switchLevelMode('mono')
                 self.__levelmode = "rgba"
                 if self.__channels is not None:
                     while len(self.__channels) < 2:
-                        self.__channels.append((self.__minval, self.__maxval))
+                        self.__channels.append(
+                            (self.__minval, self.__maxval))
                     self.updateLevels(None, None, self.__channels)
                 if self.__histogram:
-                    self.__histogram.switchLevelMode('rgba')
+                    self.__histogram.switchLevelMode('mono')
+                self.setGradient(self.__histograms[1].gradient.name, 1)
+        elif _PQGVER >= 1100:
+            if status:
+                self.__dchl = 2
+                self._updateLevelLabels()
+                if self.__ui.gradientLabel.isVisible():
+                    if not self.__histo:
+                        self.__histogram.switchLevelMode('rgba')
+                    self.__levelmode = "rgba"
+                    if self.__channels is not None:
+                        while len(self.__channels) < 2:
+                            self.__channels.append(
+                                (self.__minval, self.__maxval))
+                        self.updateLevels(None, None, self.__channels)
+                    if self.__histogram:
+                        self.__histogram.switchLevelMode('rgba')
 
     @QtCore.pyqtSlot(bool)
     def _blueLevelMode(self, status):
@@ -252,50 +336,96 @@ class LevelsGroupBox(QtGui.QWidget):
         :param status: button status
         :type status: :obj:`bool`
         """
-        if _PQGVER >= 1100:
+        if self.__gradientcolors:
             if status:
                 self.__dchl = 3
                 self._updateLevelLabels()
                 if not self.__histo:
-                    self.__histogram.switchLevelMode('rgba')
+                    self.__histogram.switchLevelMode('mono')
                 self.__levelmode = "rgba"
                 if self.__channels is not None:
                     while len(self.__channels) < 3:
-                        self.__channels.append((self.__minval, self.__maxval))
+                        self.__channels.append(
+                            (self.__minval, self.__maxval))
                     self.updateLevels(None, None, self.__channels)
                 if self.__histogram:
-                    self.__histogram.switchLevelMode('rgba')
+                    self.__histogram.switchLevelMode('mono')
+                self.setGradient(self.__histograms[2].gradient.name, 2)
+        elif _PQGVER >= 1100:
+            if status:
+                self.__dchl = 3
+                if self.__ui.gradientLabel.isVisible():
+                    self._updateLevelLabels()
+                    if not self.__histo:
+                        self.__histogram.switchLevelMode('rgba')
+                    self.__levelmode = "rgba"
+                    if self.__channels is not None:
+                        while len(self.__channels) < 3:
+                            self.__channels.append(
+                                (self.__minval, self.__maxval))
+                        self.updateLevels(None, None, self.__channels)
+                    if self.__histogram:
+                        self.__histogram.switchLevelMode('rgba')
 
-    def __connectHistogram(self):
+    def __connectHistogram(self, iid=0):
+        """ create histogram object and connect its signals
+
+        :param iid: image id
+        :type iid: :obj:`int`
+        """
+        if not self.__histconnect[iid]:
+            self.__histograms[iid].item.sigLevelsChanged.connect(
+                self.__onLevelsSlots[iid])
+            self.__histograms[iid].sigNameChanged.connect(
+                self.__changeGradientSlots[iid])
+            self.__histograms[iid].saveGradientRequested.connect(
+                self.__saveGradientSlots[iid])
+            self.__histograms[iid].removeGradientRequested.connect(
+                self.__removeGradientSlots[iid])
+            self.__histconnect[iid] = True
+        # else:
+        #     print("WARN: trying to connect HIS", iid)
+
+    def __disconnectHistogram(self, iid=0):
+        """ remove histogram object and disconnect its signals
+
+        :param iid: image id
+        :type iid: :obj:`int`
+        """
+        if self.__histconnect[iid]:
+            self.__histograms[iid].item.sigLevelsChanged.disconnect(
+                self.__onLevelsSlots[iid])
+            self.__histograms[iid].sigNameChanged.disconnect(
+                self.__changeGradientSlots[iid])
+            self.__histograms[iid].saveGradientRequested.disconnect(
+                self.__saveGradientSlots[iid])
+            self.__histograms[iid].removeGradientRequested.disconnect(
+                self.__removeGradientSlots[iid])
+            self.__histconnect[iid] = False
+        # else:
+        #     print("WARN: trying to disconnect HIS", iid)
+
+    def __connectHistograms(self):
         """ create histogram object and connect its signals
         """
-        self.__histogram.item.sigLevelsChanged.connect(
-            self._onLevelsChanged)
-        self.__histogram.sigNameChanged.connect(
-            self._changeGradient)
-        self.__histogram.saveGradientRequested.connect(
-            self._saveGradient)
-        self.__histogram.removeGradientRequested.connect(
-            self._removeGradient)
+        for iid in range(3):
+            if self.__histograms[iid].isVisible():
+                self.__connectHistogram(iid)
 
-    def __disconnectHistogram(self):
+    def __disconnectHistograms(self):
         """ remove histogram object and disconnect its signals
         """
-        self.__histogram.item.sigLevelsChanged.disconnect(
-            self._onLevelsChanged)
-        self.__histogram.sigNameChanged.disconnect(
-            self._changeGradient)
-        self.__histogram.saveGradientRequested.disconnect(
-            self._saveGradient)
-        self.__histogram.removeGradientRequested.disconnect(
-            self._removeGradient)
+        for iid in range(3):
+            if self.__histograms[iid].isVisible():
+                self.__disconnectHistogram(iid)
 
     def updateCustomGradients(self, gradients):
         self.__customgradients = dict(gradients)
         for name, gradient in self.__customgradients.items():
             _pg.graphicsItems.GradientEditorItem.Gradients[name] = gradient
             self._addGradientItem(name)
-        self.__histogram.resetGradient()
+        for iid in range(3):
+            self.__histograms[iid].resetGradient()
         self._updateGradient()
 
     def __connectMinMax(self):
@@ -325,11 +455,17 @@ class LevelsGroupBox(QtGui.QWidget):
                 if self.__histo:
                     lowlim = self.__ui.minDoubleSpinBox.value()
                     uplim = self.__ui.maxDoubleSpinBox.value()
-                    if self.__dchl == 0:
-                        self.__histogram.region.setRegion([lowlim, uplim])
+                    if self.__gradientcolors and self.__rgbstatus:
+                        for iid in range(3):
+                            if not self.__dchl or iid + 1 == self.__dchl:
+                                self.__histograms[iid].region.setRegion(
+                                    [lowlim, uplim])
                     else:
-                        self.__histogram.regions[self.__dchl].setRegion(
-                            [lowlim, uplim])
+                        if self.__dchl == 0:
+                            self.__histogram.region.setRegion([lowlim, uplim])
+                        else:
+                            self.__histogram.regions[self.__dchl].setRegion(
+                                [lowlim, uplim])
             finally:
                 self.__connectMinMax()
                 if self.__histo:
@@ -359,15 +495,14 @@ class LevelsGroupBox(QtGui.QWidget):
         :param showadd: if additional histogram should be shown
         :type showadd: :obj:`bool`
         """
-
         if showhistogram is True and self.__histo is False:
-            self.__connectHistogram()
-            self.__histogram.show()
-            self.__histogram.fillHistogram(True)
+            if showhistogram is not None:
+                self.__histo = showhistogram
+            self.showHistograms(True)
         elif showhistogram is False and self.__histo is True:
-            self.__histogram.hide()
-            self.__histogram.fillHistogram(False)
-            self.__disconnectHistogram()
+            if showhistogram is not None:
+                self.__histo = showhistogram
+            self.showHistograms(False)
         if showadd is True:
             self.__ui.binsComboBox.show()
             self.__ui.binsLabel.show()
@@ -404,8 +539,6 @@ class LevelsGroupBox(QtGui.QWidget):
             self.__ui.minLabel.hide()
             self.__ui.scalingLabel.hide()
 
-        if showhistogram is not None:
-            self.__histo = showhistogram
         if showlevels is not None:
             self.__levels = showlevels
 
@@ -445,9 +578,11 @@ class LevelsGroupBox(QtGui.QWidget):
             if fstep <= 0:
                 fstep = None
                 self.__ui.stepLineEdit.setText("")
-            self.__histogram.setStep(fstep)
+            for histogram in self.__histograms:
+                histogram.setStep(fstep)
         except Exception:
-            self.__histogram.setStep(None)
+            for histogram in self.__histograms:
+                histogram.setStep(None)
             self.__ui.stepLineEdit.setText("")
         self.levelsChanged.emit()
 
@@ -466,10 +601,12 @@ class LevelsGroupBox(QtGui.QWidget):
             elif ffactor > 100:
                 ffactor = 100
                 self.__ui.autofactorLineEdit.setText("100")
-            self.__histogram.setAutoFactor(ffactor)
+            for histogram in self.__histograms:
+                histogram.setAutoFactor(ffactor)
             self.autoLevelsChanged.emit(1)
         except Exception:
-            self.__histogram.setAutoFactor(None)
+            for histogram in self.__histograms:
+                histogram.setAutoFactor(None)
             self.autoLevelsChanged.emit(2 if self.__auto else 0)
         self.levelsChanged.emit()
 
@@ -492,18 +629,43 @@ class LevelsGroupBox(QtGui.QWidget):
                 elif ffactor > 100:
                     ffactor = 100
                     self.__ui.autofactorLineEdit.setText("100")
-                self.__histogram.setAutoFactor(ffactor)
+                    for histogram in self.__histograms:
+                        histogram.setAutoFactor(ffactor)
             except Exception:
-                self.__histogram.setAutoFactor(None)
+                for histogram in self.__histograms:
+                    histogram.setAutoFactor(None)
                 self.autoLevelsChanged.emit(2)
         else:
-            self.__histogram.setAutoFactor(None)
+            for histogram in self.__histograms:
+                histogram.setAutoFactor(None)
             self.__auto = False
             self.__showControls()
             self.autoLevelsChanged.emit(0)
             self._checkAndEmit()
         self.levelsChanged.emit()
 
+    @QtCore.pyqtSlot(object)
+    def _onLevelsChanged1(self, histogram=None):
+        """ set min/max level spinboxes according to histogram
+
+        :param histogram: intensity histogram object
+        :type histogram: :class: `lavuelib.histogramWidget.HistogramHLUTWidget`
+        """
+        if histogram is None:
+            histogram = self.__histograms[1]
+        self._onLevelsChanged(histogram)
+
+    @QtCore.pyqtSlot(object)
+    def _onLevelsChanged2(self, histogram=None):
+        """ set min/max level spinboxes according to histogram
+
+        :param histogram: intensity histogram object
+        :type histogram: :class: `lavuelib.histogramWidget.HistogramHLUTWidget`
+        """
+        if histogram is None:
+            histogram = self.__histograms[2]
+        self._onLevelsChanged(histogram)
+
     @QtCore.pyqtSlot(object)
     def _onLevelsChanged(self, histogram=None):
         """ set min/max level spinboxes according to histogram
@@ -532,14 +694,16 @@ class LevelsGroupBox(QtGui.QWidget):
                 if self.__dchl == 0:
                     self.__ui.minDoubleSpinBox.setValue(levels[0])
                     self.__ui.maxDoubleSpinBox.setValue(levels[1])
-            # #TODO channels
             if hasattr(self.__histogram, "regions") and \
                self.__channels is not None:
                 while len(self.__channels) < 3:
                     self.__channels.append((self.__minval, self.__maxval))
                     added = True
                 for i in range(1, 4):
-                    levels = histogram.regions[i].getRegion()
+                    if self.__gradientcolors and self.__rgbstatus:
+                        levels = self.__histograms[i - 1].region.getRegion()
+                    else:
+                        levels = histogram.regions[i].getRegion()
                     lowlim = self.__channels[i - 1][0]
                     uplim = self.__channels[i - 1][1]
                     added = False
@@ -649,8 +813,10 @@ class LevelsGroupBox(QtGui.QWidget):
                     ch = self.__channels[self.__dchl - 1]
                     if ch is not None:
                         chl, chh = ch
-                        self.__ui.minDoubleSpinBox.setValue(chl)
-                        self.__ui.maxDoubleSpinBox.setValue(chh)
+                        if chl is not None:
+                            self.__ui.minDoubleSpinBox.setValue(chl)
+                        if chh is not None:
+                            self.__ui.maxDoubleSpinBox.setValue(chh)
         finally:
             if not signals:
                 self.__connectMinMax()
@@ -660,7 +826,10 @@ class LevelsGroupBox(QtGui.QWidget):
             update = False
             try:
                 if self.__histo:
-                    self.__disconnectHistogram()
+                    if self.__gradientcolors and self.__rgbstatus:
+                        self.__disconnectHistograms()
+                    else:
+                        self.__disconnectHistogram()
 
                 if levels[0] != lowlim or levels[1] != uplim or force:
                     if self.__histo:
@@ -671,15 +840,27 @@ class LevelsGroupBox(QtGui.QWidget):
                             if ch is not None:
                                 lowlim, uplim = ch
                                 if lowlim is not None and uplim is not None:
-                                    levels = self.__histogram.regions[i + 1]\
-                                                             .getRegion()
-                                    if levels[0] != lowlim \
-                                       or levels[1] != uplim or force:
-                                        self.__histogram.regions[i + 1].\
-                                            setRegion([lowlim, uplim])
+                                    if self.__gradientcolors and \
+                                       self.__rgbstatus:
+                                        levels = self.__histograms[i].region\
+                                            .getRegion()
+                                        if levels[0] != lowlim \
+                                           or levels[1] != uplim or force:
+                                            self.__histograms[i].region.\
+                                                setRegion([lowlim, uplim])
+                                    else:
+                                        levels = self.__histogram.\
+                                            regions[i + 1].getRegion()
+                                        if levels[0] != lowlim \
+                                           or levels[1] != uplim or force:
+                                            self.__histogram.regions[i + 1].\
+                                                setRegion([lowlim, uplim])
             finally:
                 if self.__histo:
-                    self.__connectHistogram()
+                    if self.__gradientcolors and self.__rgbstatus:
+                        self.__connectHistograms()
+                    else:
+                        self.__connectHistogram()
             if update:
                 self._onLevelsChanged()
         self._emitLevels()
@@ -702,7 +883,12 @@ class LevelsGroupBox(QtGui.QWidget):
             ulim = None
             if self.__histo:
                 llim, ulim = self.__histogram.getFactorRegion()
-                channels = self.__histogram.getChannelFactorRegion()
+                if self.__gradientcolors and self.__rgbstatus:
+                    channels = [(llim, ulim)]
+                    channels.append(self.__histograms[1].getFactorRegion())
+                    channels.append(self.__histograms[2].getFactorRegion())
+                else:
+                    channels = self.__histogram.getChannelFactorRegion()
             if channels is not None:
                 self.__channels = channels
             if llim is not None and ulim is not None:
@@ -793,6 +979,17 @@ class LevelsGroupBox(QtGui.QWidget):
             uplim = math.sqrt(max(math.pow(10, uplim), 0))
         return lowlim, uplim
 
+    @QtCore.pyqtSlot(str)
+    def setRGBChannels(self, rgbchannels):
+        """ rgb channel indexes
+
+        :param rgbchannels: rgb channel indexes
+        :type rgbchannels: :obj:`tuple` <:obj:`int`>
+        """
+        if self.__rgbchannels != rgbchannels:
+            self.__rgbchannels = rgbchannels
+        self.showHistograms(self.__rgbstatus)
+
     @QtCore.pyqtSlot(str)
     def setScalingLabel(self, scalingtype):
         """ sets scaling label
@@ -800,8 +997,6 @@ class LevelsGroupBox(QtGui.QWidget):
         :param scalingtype: scaling type, i.e. log, linear, sqrt
         :type scalingtype: :obj:`str`
         """
-        # TODO channels
-
         lowlim = float(self.__ui.minDoubleSpinBox.value())
         uplim = float(self.__ui.maxDoubleSpinBox.value())
         scalefun = {
@@ -866,19 +1061,66 @@ class LevelsGroupBox(QtGui.QWidget):
         :param status: True for on and False for off
         :type status: :obj:`bool`
         """
-        self.__histogram.setRGB(status)
-        if status and self.__dchl:
+        self.__histogram.setRGB(status and not self.__gradientcolors)
+        if status and self.__dchl and not self.__gradientcolors:
             mode = 'rgba'
+            lmode = 'rgba'
             dchl = self.__dchl
+        elif status and self.__dchl and self.__gradientcolors:
+            mode = 'mono'
+            lmode = 'rgba'
+            dchl = 0
         else:
             mode = 'mono'
+            lmode = 'mono'
             dchl = 0
+        self.__rgbstatus = status
         self.__histogram.switchLevelMode(mode)
+        self.__levelmode = lmode
         self._updateLevelLabels(dchl)
-        self.showGradient(not status)
-        if _PQGVER >= 1100:
+        self.showGradient(not status or self.__gradientcolors)
+        self.showHistograms(status)
+        if _PQGVER >= 1100 or self.__gradientcolors:
             self.showChannels(status)
 
+    def showHistograms(self, status=True):
+        """ show/hide gradient widget
+
+        :param status: show gradient flag
+        :type status: :obj:`bool`
+        """
+        if self.__gradientcolors and status and self.__histo:
+            for iid in range(0, 3):
+                if self.__rgbchannels[iid] != -1:
+                    if not self.__histograms[iid].isVisible():
+                        self.__connectHistogram(iid)
+                        self.__histograms[iid].show()
+                        self.__histograms[iid].fillHistogram(True)
+                else:
+                    if self.__histograms[iid].isVisible():
+                        self.__histograms[iid].hide()
+                        self.__histograms[iid].fillHistogram(False)
+                        self.__disconnectHistogram(iid)
+        else:
+            if self.__histo:
+                if not self.__histograms[0].isVisible():
+                    self.__connectHistogram()
+                    self.__histograms[0].show()
+                    self.__histograms[0].fillHistogram(True)
+            else:
+                if self.__histograms[0].isVisible():
+                    self.__histograms[0].hide()
+                    self.__histograms[0].fillHistogram(False)
+                    self.__disconnectHistogram()
+            if self.__histograms[1].isVisible():
+                self.__histograms[1].hide()
+                self.__histograms[1].fillHistogram(False)
+                self.__disconnectHistogram(1)
+            if self.__histograms[2].isVisible():
+                self.__histograms[2].hide()
+                self.__histograms[2].fillHistogram(False)
+                self.__disconnectHistogram(2)
+
     def showGradient(self, status=True):
         """ show/hide gradient widget
 
@@ -914,8 +1156,9 @@ class LevelsGroupBox(QtGui.QWidget):
         :param index: bins edges algorithm index for histogram
         :type index: :obj:`int`
         """
-        self.__histogram.setBins(
-            self.__ui.binsComboBox.itemText(index))
+        for histogram in self.__histograms:
+            histogram.setBins(
+                self.__ui.binsComboBox.itemText(index))
         self.levelsChanged.emit()
 
     def gradient(self):
@@ -924,12 +1167,31 @@ class LevelsGroupBox(QtGui.QWidget):
         :returns:  gradient name
         :rtype: :obj:`str`
         """
-        return str(self.__ui.gradientComboBox.currentText())
+        if self.__gradientcolors and self.__rgbstatus:
+            return str(";".join(
+                [his.gradient.name for his in self.__histograms]))
+        else:
+            return str(self.__ui.gradientComboBox.currentText())
 
     @QtCore.pyqtSlot()
-    def _saveGradient(self):
+    def _saveGradient1(self):
         """ saves the current gradient
         """
+        self._saveGradient(1)
+
+    @QtCore.pyqtSlot()
+    def _saveGradient2(self):
+        """ saves the current gradient
+        """
+        self._saveGradient(2)
+
+    @QtCore.pyqtSlot()
+    def _saveGradient(self, iid=0):
+        """ saves the current gradient
+
+        :param iid: image id
+        :type iid: :obj:`int`
+        """
         graddlg = gradientDialog.GradientDialog()
         graddlg.protectednames = list(
             set(_pg.graphicsItems.GradientEditorItem.Gradients.keys()) -
@@ -939,21 +1201,40 @@ class LevelsGroupBox(QtGui.QWidget):
         if graddlg.exec_():
             if graddlg.name:
                 name = graddlg.name
-                gradient = self.__histogram.gradient.getCurrentGradient()
+                gradient = self.__histograms[iid].gradient.getCurrentGradient()
                 self.__customgradients[name] = gradient
                 _pg.graphicsItems.GradientEditorItem.Gradients[name] = gradient
                 self._addGradientItem(name)
-                self.__histogram.resetGradient()
-                self.setGradient(name)
+                for i, histogram in enumerate(self.__histograms):
+                    lname = histogram.gradient.name
+                    histogram.resetGradient()
+                    if iid == i:
+                        lname = name
+                    self.setGradient(lname, i)
                 self._updateGradient()
                 self.__settings.setCustomGradients(self.__customgradients)
                 self.storeSettingsRequested.emit()
 
     @QtCore.pyqtSlot()
-    def _removeGradient(self):
+    def _removeGradient1(self):
         """ removes the current gradient
         """
-        name = str(self.gradient())
+        self._removeGradient(1)
+
+    @QtCore.pyqtSlot()
+    def _removeGradient2(self):
+        """ removes the current gradient
+        """
+        self._removeGradient(2)
+
+    @QtCore.pyqtSlot()
+    def _removeGradient(self, iid=0):
+        """ removes the current gradient
+
+        :param iid: image id
+        :type iid: :obj:`int`
+        """
+        name = self.__histograms[iid].gradient.name
 
         if name in self.__customgradients:
             if QtGui.QMessageBox.question(
@@ -966,7 +1247,11 @@ class LevelsGroupBox(QtGui.QWidget):
             self.__customgradients.pop(name)
             _pg.graphicsItems.GradientEditorItem.Gradients.pop(name)
             self._removeGradientItem(name)
-            self.__histogram.resetGradient()
+            for i, histogram in enumerate(self.__histograms):
+                lname = histogram.gradient.name
+                histogram.resetGradient()
+                if name != lname:
+                    self.setGradient(lname, i)
             self.__settings.setCustomGradients(self.__customgradients)
             self.storeSettingsRequested.emit()
         else:
@@ -1000,13 +1285,22 @@ class LevelsGroupBox(QtGui.QWidget):
                 "Error in _removeGradientItem for %s" % name)
             # print("Error %s" % name)
 
-    def setGradient(self, name):
+    def setGradient(self, name, iid=None):
         """ sets gradient
 
         :param name  gradient name
         :type name: :obj:`str`
+        :param iid: image id
+        :type iid: :obj:`int`
         """
-        self._changeGradient(name)
+        if iid is not None:
+            self.__changeGradientSlots[iid](name)
+        else:
+            names = name.split(";")
+            for i, nm in enumerate(names):
+                if i > 2:
+                    break
+                self.__changeGradientSlots[i](nm)
 
     @QtCore.pyqtSlot(int)
     def _updateGradient(self, index=-1):
@@ -1018,20 +1312,60 @@ class LevelsGroupBox(QtGui.QWidget):
         if index == -1:
             name = self.__ui.gradientComboBox.currentText()
             index = self.__ui.gradientComboBox.findText(name)
-        self.__histogram.setGradientByName(
-            self.__ui.gradientComboBox.itemText(index))
+        if self.__gradientcolors and self.__rgbstatus:
+            if not self.__dchl:
+                for iid in range(3):
+                    self.__histograms[iid].setGradientByName(
+                        self.__ui.gradientComboBox.itemText(index))
+            else:
+                self.__histograms[self.__dchl - 1].setGradientByName(
+                    self.__ui.gradientComboBox.itemText(index))
+        else:
+            self.__histogram.setGradientByName(
+                self.__ui.gradientComboBox.itemText(index))
         self.gradientChanged.emit()
 
     @QtCore.pyqtSlot(str)
-    def _changeGradient(self, name):
+    def _changeGradient0(self, name):
         """ updates the gradient combobox
 
         :param name: gradient name
         :type name: :obj:`str`
         """
+        self._changeGradient(name, 0)
+
+    @QtCore.pyqtSlot(str)
+    def _changeGradient1(self, name):
+        """ updates the gradient combobox
+
+        :param name: gradient name
+        :type name: :obj:`str`
+        """
+        self._changeGradient(name, 1)
+
+    @QtCore.pyqtSlot(str)
+    def _changeGradient2(self, name):
+        """ updates the gradient combobox
+
+        :param name: gradient name
+        :type name: :obj:`str`
+        """
+        self._changeGradient(name, 2)
+
+    @QtCore.pyqtSlot(str)
+    def _changeGradient(self, name, iid=0):
+        """ updates the gradient combobox
+
+        :param name: gradient name
+        :type name: :obj:`str`
+        :param iid: image id
+        :type iid: :obj:`int`
+        """
         text = self.__ui.gradientComboBox.currentText()
         if text != name:
             cid = self.__ui.gradientComboBox.findText(name)
+            if self.__gradientcolors and self.__rgbstatus:
+                self.__updateRadio(iid + 1)
             if cid > -1:
                 self.__ui.gradientComboBox.setCurrentIndex(cid)
             else:
@@ -1048,15 +1382,21 @@ class LevelsGroupBox(QtGui.QWidget):
         :type autoLevel: :obj:`bool`
         """
         auto = autoLevel if autoLevel is not None else self.__auto
-        self.__histogram.imageChanged(autoLevel=auto)
+        if self.__gradientcolors and self.__rgbstatus:
+            for histogram in self.__histograms:
+                histogram.imageChanged(autoLevel=auto)
+        else:
+            self.__histogram.imageChanged(autoLevel=auto)
 
-    def setImageItem(self, image):
+    def setImageItem(self, image, iid=0):
         """ sets histogram image
 
         :param image: histogram image
         :type image: :class:`pyqtgraph.graphicsItems.ImageItem.ImageItem`
+        :param iid: image id
+        :type iid: :obj:`int`
         """
-        self.__histogram.setImageItem(image)
+        self.__histograms[iid].setImageItem(image)
 
     def levels(self):
         """ provides levels from configuration string
@@ -1152,6 +1492,17 @@ class LevelsGroupBox(QtGui.QWidget):
                     pass
 
                 self.updateLevels(lmin, lmax, channels, force=True)
+        self.__updateRadio(dchl)
+
+    def __updateRadio(self, dchl=None):
+        """ update RGB radio button position
+
+        :param dchl: channel id
+        :type dchl: :obj:`int`
+        """
+
+        if dchl is None:
+            dchl = self.__dchl
         if dchl == 0 and not self.__ui.monoRadioButton.isChecked():
             self.__ui.monoRadioButton.click()
         elif dchl == 1 and not self.__ui.redRadioButton.isChecked():
@@ -1186,6 +1537,24 @@ class LevelsGroupBox(QtGui.QWidget):
         :return: level mode
         :rtype: :obj:`str`
         """
-        if self.__histogram and self.__histo:
-            return self.__histogram.levelMode
+        # if self.__histogram and self.__histo:
+        #     return self.__histogram.levelMode
         return self.__levelmode
+
+    def setGradientColors(self, status=True):
+        """ sets gradientcolors on/off
+
+        :param status: True for on and False for off
+        :type status: :obj:`bool`
+        """
+        if self.__gradientcolors != status:
+            self.__gradientcolors = status
+            self.showHistograms(self.__rgbstatus)
+
+    def gradientColors(self):
+        """ gets gradientcolors on/off
+
+        :returns: True for on and False for off
+        :rtype: :obj:`bool`
+        """
+        return self.__gradientcolors
